@@ -1,17 +1,20 @@
+#![deny(warnings)]
+
 //! Provides convenient functions and macro to build dynamic css
 #![doc = include_str!("../README.md")]
 
+#[doc(hidden)]
 pub use json;
+
 pub mod prelude {
     pub use crate::*;
-    pub use style::*;
     pub use units::*;
 }
 
 pub mod style;
 pub mod units;
 
-/// build css using json notation
+/// Creates css using json notation
 /// ```rust
 /// use jss::jss;
 /// let css = jss!(
@@ -183,7 +186,19 @@ fn process_css_selector_map(
         if use_indents {
             buffer += " ";
         }
-        buffer += &process_css_properties(indent, namespace, style_properties, use_indents);
+        buffer += "{";
+        if use_indents {
+            buffer += "\n";
+        }
+        buffer += &process_css_properties(
+            indent,
+            namespace,
+            Some(classes),
+            style_properties,
+            use_indents,
+        );
+        buffer += &make_indent(indent, use_indents);
+        buffer += "}";
     }
     buffer
 }
@@ -192,15 +207,12 @@ fn process_css_selector_map(
 pub fn process_css_properties(
     indent: usize,
     namespace: Option<&str>,
+    _classes: Option<&str>,
     style_properties: &json::JsonValue,
     use_indents: bool,
 ) -> String {
     let mut buffer = String::new();
 
-    buffer += "{";
-    if use_indents {
-        buffer += "\n";
-    }
     for (prop, value) in style_properties.entries() {
         if value.is_object() {
             // recursive call to process_css_selector_map to support multiple layer of json object used in
@@ -214,7 +226,29 @@ pub fn process_css_properties(
             let style_name = if let Some(style_name) = style::from_ident(prop) {
                 style_name
             } else {
-                style::match_name(prop).unwrap_or_else(|| panic!("invalid style name: {}", prop))
+                let matched_property = style::match_name(prop);
+                if let Some(matched_property) = matched_property {
+                    matched_property
+                } else {
+                    // if strict, do a panic
+                    #[cfg(feature = "strict")]
+                    {
+                        panic!(
+                            "invalid style name: `{}` {}",
+                            prop,
+                            if let Some(classes) = _classes {
+                                format!("in selector: `{}`", classes)
+                            } else {
+                                "".to_string()
+                            }
+                        );
+                    }
+                    // if not strict return the prop as is
+                    #[cfg(not(feature = "strict"))]
+                    {
+                        prop
+                    }
+                }
             };
             let value_str = match value {
                 json::JsonValue::String(s) => s.to_string(),
@@ -248,8 +282,6 @@ pub fn process_css_properties(
             }
         }
     }
-    buffer += &make_indent(indent, use_indents);
-    buffer += "}";
 
     buffer
 }
